const jwt = require('jsonwebtoken');
const crypto = require('crypto');

class Auth {
	constructor() {
	}
	createSalt() {
		let genRandomString = function(length){
			return crypto.randomBytes(Math.ceil(length/2))
			.toString('hex') /** convert to hexadecimal format */
			.slice(0,length);/** return required number of characters */
		};
		return genRandomString(16); /** Gives us salt of length 16 */
	}
	createHash(salt="", password) {
		/*
		** hash password with sha512.
		** @function
		** @param {string} password - List of required fields.
		** @param {string} salt - Data to be validated.
		*/
		let sha512 = function(password, salt){
			let hash = crypto.createHmac('sha512', salt); /** Hashing algorithm sha512 */
			hash.update(password);
			return hash.digest('hex');
		};
		let passwordData = sha512(password, salt);
		return passwordData;
	}
	generateJWT(secret) {
		return function (options={}) {
			let today = new Date();
			let exp = new Date(today);
			exp.setDate(today.getDate() + options.duration || 60);
			let payload = {
				exp: parseInt(exp.getTime() / 1000),
			};
			if (options.attributes && options.attributes.length > 0) {
				for (let i = 0; i < options.attributes.length; i++) {
					let attributeName = options.attributes[i];
					payload[attributeName] = this[attributeName];
				}
			}
			let token = jwt.sign(payload, secret);
			return token;
		};
	}
	generateResetToken() {
		return new Promise((resolve, reject)=>{
			crypto.randomBytes(20, (err, buf)=>{
				if (err) return reject(err);
				let token = buf.toString('hex');
				resolve(token);
			});
		});
	}
}

module.exports = Auth;
