const assert = require('assert');
const should = require('should');
const MockBrowser = require('mock-browser').mocks.MockBrowser;
const mock = new MockBrowser();
const document = mock.getDocument();

const DOM = require('../index').DOM;

describe(`# DOM`, function () {
	describe(`* addClass()`, function () {
		it(`should add class to a DOM element.`, function () {
			let ele = document.createElement('div');
			ele.className = 'hello';
			DOM.addClass('goodbye', ele);
			assert('hello goodbye', ele.className);
		});
	});
	describe(`* removeClass()`, function () {
		it(`should remove class to a DOM element.`, function () {
			let ele = document.createElement('div');
			ele.className = 'hello goodbye';
			DOM.removeClass('goodbye', ele);
			assert.equal('hello', ele.className);
		});
	});
	describe(`* findSibling(ele, delta)`, function () {
		let parent = document.createElement('div');
		parent.className = 'parent';
		let first = document.createElement('div');
		first.className = 'first';
		let second = document.createElement('div');
		second.className = 'second';
		let last = document.createElement('div');
		last.className = 'last';
		parent.appendChild(first);
		parent.appendChild(second);
		parent.appendChild(last)
		it(`should return a next sibling when delta = +1`, function () {
			let next = DOM.findSibling(second, +1);
			assert.equal(next, last);
		});
		it(`should return a prev sibling when delta = -1`, function () {
			let prev = DOM.findSibling(second, -1);
			assert.equal(prev, first);
		});
	})
});
